# CHANGELOG


## v1.6.0-dev.2 (2025-08-12)

### Features

- Update readme
  ([`e966927`](https://github.com/opentargets/gentroutils/commit/e966927f8c4b3c670c694258c65eb6b3da6eeb49))


## v1.6.0-dev.1 (2025-08-12)

### Features

- Version 2.0.0
  ([`47c9690`](https://github.com/opentargets/gentroutils/commit/47c9690ffc23be713ef0246aae5271ebe2ab5e3a))


## v1.5.0 (2025-02-12)


## v1.5.0-dev.1 (2025-02-12)

### Features

- Use semvar-release token
  ([`e03d14c`](https://github.com/opentargets/gentroutils/commit/e03d14ca35d9ea68bce44a3f81e852848933958a))


## v1.4.0 (2025-02-12)


## v1.4.0-dev.1 (2025-02-12)

### Features

- Use default token
  ([`7fde0f2`](https://github.com/opentargets/gentroutils/commit/7fde0f2704521e6db45811d2f65306beaa0a85d4))


## v1.3.0 (2025-02-12)


## v1.3.0-dev.3 (2025-02-12)

### Features

- Ensure proper username
  ([`fe2e490`](https://github.com/opentargets/gentroutils/commit/fe2e49068cf51613907d2979ee88fd35dfeb4ec9))


## v1.3.0-dev.2 (2025-02-12)

### Features

- Ensure push is run on main branch only
  ([`1e27c7b`](https://github.com/opentargets/gentroutils/commit/1e27c7bb2dcf9fc1be3067b60d28e98c3945a44f))


## v1.3.0-dev.1 (2025-02-12)

### Features

- Push with github token
  ([`3d78465`](https://github.com/opentargets/gentroutils/commit/3d784653d005844a4f458f0d96a430cb5eb40eca))


## v1.2.0 (2025-02-12)


## v1.2.0-dev.2 (2025-02-12)

### Features

- Merge dev to main when tag is commited
  ([`8f8f462`](https://github.com/opentargets/gentroutils/commit/8f8f462820110ca40a4079f444baf40b8afaf19d))


## v1.2.0-dev.1 (2025-02-12)


## v1.1.0 (2025-02-12)


## v1.1.0-dev.2 (2025-02-12)

### Features

- Drop reusable workflow
  ([`cc982d9`](https://github.com/opentargets/gentroutils/commit/cc982d961b016846c2d406e7fc214593130ceebd))


## v1.1.0-dev.1 (2025-02-12)


## v1.0.0 (2025-02-12)

### Chores

- Update readme
  ([`61e962a`](https://github.com/opentargets/gentroutils/commit/61e962a37d8b919fdadea3500a9381a71be0783b))

### Features

- Debug pypi upload process
  ([`0ac7131`](https://github.com/opentargets/gentroutils/commit/0ac7131bf9d2fc5d8b68e5f45710e34247ffbf23))


## v1.0.0-dev.5 (2025-02-12)

### Features

- Update uv lock
  ([`c3c2979`](https://github.com/opentargets/gentroutils/commit/c3c297922b251f8d8893553152e39296940da8ba))


## v1.0.0-dev.4 (2025-02-12)

### Features

- Remove development release
  ([`f98fdf8`](https://github.com/opentargets/gentroutils/commit/f98fdf8cd6819ba60113a9d716afd322e3da5234))


## v1.0.0-dev.3 (2025-02-12)


## v0.2.0 (2024-12-06)

### Chores

- Cleanup
  ([`32f8b8d`](https://github.com/opentargets/gentroutils/commit/32f8b8d1f5d1505569a44ed6ae0ff81e1a9c80de))

- Delete coverage file
  ([`c720041`](https://github.com/opentargets/gentroutils/commit/c720041d699d9dd6fcbd4e4feb621400ffc5703d))

- Fix conflicts
  ([`5fcc649`](https://github.com/opentargets/gentroutils/commit/5fcc649266047fe65caa2b33d125a10c550e1ade))

- Linting
  ([`429102c`](https://github.com/opentargets/gentroutils/commit/429102c3195c09933b57775051b404fad933dda3))

### Documentation

- **validate_curation**: Added example command to readme
  ([`e6c38d0`](https://github.com/opentargets/gentroutils/commit/e6c38d0eddae66fd8825f235837bdc7cb9758e1c))

### Features

- Curation
  ([`bb1f7ea`](https://github.com/opentargets/gentroutils/commit/bb1f7eaf82a7d669129f20cedba0429091d16300))

- Curation validator
  ([`3b8e269`](https://github.com/opentargets/gentroutils/commit/3b8e2697636abade55f68088a840dabea7011c4f))

- Pyftpdlib
  ([`3f5a554`](https://github.com/opentargets/gentroutils/commit/3f5a55420fd30c768d1ce437b87e5296b09a98ea))

### Testing

- Curation validation
  ([`53b571e`](https://github.com/opentargets/gentroutils/commit/53b571ed6849da709f3b2b6c897469f428d8048b))

- Mock ebi ftp server
  ([`3b5d4b7`](https://github.com/opentargets/gentroutils/commit/3b5d4b74825a951c5f0be12759c6051e21a0ff9d))

- **curation validation**: Add test cases for expectations
  ([`85e6a25`](https://github.com/opentargets/gentroutils/commit/85e6a2566751d90ec9ceb5272e0eec3f408119e1))


## v1.0.0-dev.2 (2025-02-12)

### Features

- Ensure the url is present in the env
  ([`873130a`](https://github.com/opentargets/gentroutils/commit/873130a543e3ac5da0e515a2c663d902720fef93))


## v1.0.0-dev.1 (2025-02-12)

### Features

- Change release token to dev
  ([`1ff5138`](https://github.com/opentargets/gentroutils/commit/1ff51383fae579916413e58178762edad4ca3239))


## v1.0.0-rc.11 (2025-02-12)

### Features

- Revert name removal
  ([`6972951`](https://github.com/opentargets/gentroutils/commit/69729519972650b1e865c7e7eb9b40c2ca20cabb))


## v1.0.0-rc.10 (2025-02-12)

### Features

- Drop workflow name
  ([`ff382dc`](https://github.com/opentargets/gentroutils/commit/ff382dc6e29f89d985df35631556e07759d22548))


## v1.0.0-rc.9 (2025-02-12)

### Features

- Dev environment deployment trigger
  ([`5401de5`](https://github.com/opentargets/gentroutils/commit/5401de5c7d38057776d81bd7722db5c7b1aa8d15))


## v1.0.0-rc.8 (2025-02-11)

### Features

- Change to test env for test pypi release
  ([`0f4bfd4`](https://github.com/opentargets/gentroutils/commit/0f4bfd4aed78f8a7ccb6173005323249342204ed))


## v1.0.0-rc.7 (2025-02-11)

### Features

- Allow trusted publisher in pypi actions
  ([`48d3ca4`](https://github.com/opentargets/gentroutils/commit/48d3ca451ebd9f0343dc4d9bdd0bcbaee8755db9))


## v1.0.0-rc.6 (2025-02-11)

### Features

- Allow trusted publisher in pypi actions
  ([`3179d8c`](https://github.com/opentargets/gentroutils/commit/3179d8cd650cc1f4953b05cd7df02fe7d790a3fd))


## v1.0.0-rc.5 (2025-02-11)

### Features

- Allow trusted publisher in pypi actions
  ([`3e73526`](https://github.com/opentargets/gentroutils/commit/3e73526724ee1d43d7f1f6029a7a81a109b2bfb4))


## v1.0.0-rc.4 (2025-02-11)

### Features

- Add release badge
  ([`cfb39e2`](https://github.com/opentargets/gentroutils/commit/cfb39e26fb54b83b4760d324c58a89d337d87402))

- Preparation for dev release
  ([`daca0aa`](https://github.com/opentargets/gentroutils/commit/daca0aa86ace460a5c74b4943c187e874d6d6fad))

* fix workflow names * fix workflow badges in README * update uv lock


## v1.0.0-rc.3 (2025-02-11)

### Bug Fixes

- Incorrect python version in gha
  ([`ec2f701`](https://github.com/opentargets/gentroutils/commit/ec2f7013dc52102a1a25ac59b400ee6fb2c7b888))

### Chores

- Add name to tag action
  ([`d93d8a3`](https://github.com/opentargets/gentroutils/commit/d93d8a3c65812a6ee7064a8a2d676363167f3ade))


## v1.0.0-rc.2 (2025-02-11)

### Features

- Reusable workflow for release
  ([`67eb06b`](https://github.com/opentargets/gentroutils/commit/67eb06b253cb850a7300cd59849bbd2c0571ae9e))


## v1.0.0-rc.1 (2025-02-11)

### Bug Fixes

- Upload log file only when not dry-run
  ([`57c8a8e`](https://github.com/opentargets/gentroutils/commit/57c8a8eafd0deb37221fb990c72e77d9f1c9bf6c))

- Use user defined shell
  ([`0fa2cff`](https://github.com/opentargets/gentroutils/commit/0fa2cff0300cad96f22efdc1584fb68817ed2ac6))

- Use user shell only for installation
  ([`40129e5`](https://github.com/opentargets/gentroutils/commit/40129e5b6ed88cd21eaa8b0666c1988ae0ef2290))

### Chores

- Cleanup
  ([`2977878`](https://github.com/opentargets/gentroutils/commit/2977878c129746d304ff6d38ba3400d942f367c9))

- Delete coverage file
  ([`5d7e1f2`](https://github.com/opentargets/gentroutils/commit/5d7e1f2ad063bdd52e9ec7f70ffc4abe0b4311e4))

- Fix author
  ([`108ea30`](https://github.com/opentargets/gentroutils/commit/108ea3092221f565f3983d44604d3046e761660b))

- Linting
  ([`4d762d1`](https://github.com/opentargets/gentroutils/commit/4d762d1e88a606a7e15f138297599dac657c6504))

- Update README file
  ([`afe6932`](https://github.com/opentargets/gentroutils/commit/afe6932d14266d9d266276c1ff9c0458f6b9712a))

- **dependency management**: Replace rye with uv
  ([`cb60d0b`](https://github.com/opentargets/gentroutils/commit/cb60d0be7d2e03eddf85cdecef352070c4edfaf8))

### Documentation

- **validate_curation**: Added example command to readme
  ([`071aad3`](https://github.com/opentargets/gentroutils/commit/071aad3e53ccd9735bcf4b444670f79128b54954))

### Features

- Curation
  ([`c9cca7c`](https://github.com/opentargets/gentroutils/commit/c9cca7c080c3106246ea1c00cb113198cccac07b))

- Curation validator
  ([`5865019`](https://github.com/opentargets/gentroutils/commit/58650190f6b5790142bbe1a1b641993ab9fbea97))

- Pyftpdlib
  ([`fbf2da1`](https://github.com/opentargets/gentroutils/commit/fbf2da12846de12a9a09d93e3c085a0dfbc50e26))

- Remove redundant files from curation update command
  ([`f3fb1e8`](https://github.com/opentargets/gentroutils/commit/f3fb1e8baed554d6f257ae6f051115ad8e92602f))

- Update default command help
  ([`c8b2c3a`](https://github.com/opentargets/gentroutils/commit/c8b2c3a390d56bcc07406926ba45080a4b4dd74c))

- Workflow on pr
  ([`8340162`](https://github.com/opentargets/gentroutils/commit/8340162afc5b9569b66c9dad570287d47278c880))

- **dev_process**: Changes to development process
  ([`9096a4e`](https://github.com/opentargets/gentroutils/commit/9096a4e09d0cf36ffb3cc5511a54636f6f799c3f))

BREAKING CHANGE: swap rye with uv feat: update github actions workflows

### Testing

- Curation validation
  ([`a1c896b`](https://github.com/opentargets/gentroutils/commit/a1c896b8f2fa2788b66e9f3b1a22830db84526ca))

- Mock ebi ftp server
  ([`a9aef25`](https://github.com/opentargets/gentroutils/commit/a9aef25111f7de0d2ec053f733e54d0972ff9348))

- **curation validation**: Add test cases for expectations
  ([`7037c0b`](https://github.com/opentargets/gentroutils/commit/7037c0be0241b01d5c566b9e40393b338edb3a37))

### Breaking Changes

- **dev_process**: Swap rye with uv feat: update github actions workflows


## v0.1.5 (2024-08-13)


## v0.1.4 (2024-08-13)


## v0.1.3 (2024-08-13)


## v0.1.2 (2024-08-13)


## v0.1.1 (2024-08-13)


## v0.1.0 (2024-08-13)

### Bug Fixes

- Add cargo to rc file
  ([`7e1340f`](https://github.com/opentargets/gentroutils/commit/7e1340f1fb4aa57092f149db0e9400d18a4a0cca))

- Debug ci
  ([`cd0c7ed`](https://github.com/opentargets/gentroutils/commit/cd0c7eda865af9df5bf1ab65dfa405b3a13e605c))

- Debug v2
  ([`332e0d5`](https://github.com/opentargets/gentroutils/commit/332e0d58dee315c9aa5f57f20464d1097c41cb59))

- Ensure pip is installed for pre-commit action
  ([`7d74378`](https://github.com/opentargets/gentroutils/commit/7d74378a45c307b9ae64cd6dfd707948113b5e7d))

- Fix dev branch test run
  ([`967c0b8`](https://github.com/opentargets/gentroutils/commit/967c0b83d3e1c4f6e9c7c2d909fbb71674ec8871))

- Fix dev branch test run
  ([`8430526`](https://github.com/opentargets/gentroutils/commit/8430526f911fbe91c58131056f091cbd11ef2e15))

- Moved ci file
  ([`c2626a2`](https://github.com/opentargets/gentroutils/commit/c2626a2479217e1e0e4a36470503d3a1f19f3021))

- Remove local log file
  ([`b2a80fc`](https://github.com/opentargets/gentroutils/commit/b2a80fceceeb34832ddc271c28c8de9363e3b745))

- Run pre-commit by rye
  ([`7fbd06c`](https://github.com/opentargets/gentroutils/commit/7fbd06cbeb42563f6c2a66f768e490f554a7c07b))

- Typo in package name
  ([`10584a5`](https://github.com/opentargets/gentroutils/commit/10584a56790cf4693bd47ee3e50672bc4bb78068))

### Build System

- Added deptry
  ([`179f196`](https://github.com/opentargets/gentroutils/commit/179f196e766185ba8a54a5292a2aedf80e45b4ab))

- Added mypy
  ([`ccf0750`](https://github.com/opentargets/gentroutils/commit/ccf07504df5350063ad0c3cdc1e38876a14f5507))

- Added pydoclint
  ([`633b3da`](https://github.com/opentargets/gentroutils/commit/633b3da1623c41da519c9ad5f0caf747648a051e))

- Dev setup make target
  ([`0dda8bd`](https://github.com/opentargets/gentroutils/commit/0dda8bdab571d925e2a42e66fa0dc7809b2da68f))

- Docstring linting
  ([`5feea17`](https://github.com/opentargets/gentroutils/commit/5feea17a28241dd7f4ecd43ebb7c4e34e0fd8301))

- Precommit & interrogate
  ([`8ae6533`](https://github.com/opentargets/gentroutils/commit/8ae6533e757551fbe32d386725deeeb27def2ed7))

- Ruff setup
  ([`daddc69`](https://github.com/opentargets/gentroutils/commit/daddc6949bb2d8e39783e2837a85a3b853825590))

### Chores

- Added licence
  ([`bac9b9d`](https://github.com/opentargets/gentroutils/commit/bac9b9d20279ce08623571fa29bf43d8d63fab83))

- Added project description and classifiers
  ([`8ef35fa`](https://github.com/opentargets/gentroutils/commit/8ef35fa58842c5ccac7d69fb5dfb20849d7cdc86))

- Badge
  ([`d92782b`](https://github.com/opentargets/gentroutils/commit/d92782b8ccced842e8fa853f00c298b432e759c8))

- Licence badge
  ([`93708ba`](https://github.com/opentargets/gentroutils/commit/93708bad3bbc1d65cc0f87faad4cbe14856bbf93))

### Continuous Integration

- Add pypi release
  ([`271abbf`](https://github.com/opentargets/gentroutils/commit/271abbfe125f44db11c078f6b3ff91e7748551de))

- Added manual trigger for release trigger job
  ([`911ba3f`](https://github.com/opentargets/gentroutils/commit/911ba3f42a81055dd006c8f1020ffdb315357eac))

- Added needs flags to release jobs
  ([`3b84cdd`](https://github.com/opentargets/gentroutils/commit/3b84cdd3d4e158f172d29ccc27d033facd56e244))

- Changed ga workflow names
  ([`caab806`](https://github.com/opentargets/gentroutils/commit/caab806457f36c84556422ef61eeed6a219e6bb6))

- Changed how uv and rye are installed
  ([`e7c9e5e`](https://github.com/opentargets/gentroutils/commit/e7c9e5e2dec910aa9cef2b14b1d88d4e669c057a))

- Ci test release
  ([`8c98b46`](https://github.com/opentargets/gentroutils/commit/8c98b46b40e5779eb789b3b510d0352dc45a34f0))

- Fix link to testpypi
  ([`aa19be5`](https://github.com/opentargets/gentroutils/commit/aa19be588dcf2e93e862efc9e3ab54e06c3e762e))

- Fix link to testpypi
  ([`b14085d`](https://github.com/opentargets/gentroutils/commit/b14085dd05bbb85c3e9a49742f59ff9043c391b0))

- Fix path to the semvar version
  ([`614f3a7`](https://github.com/opentargets/gentroutils/commit/614f3a753fb562264fb05189ee27c16a522cfcbc))

- Fix repo name in checkout action for tag
  ([`c49ee91`](https://github.com/opentargets/gentroutils/commit/c49ee911455468650a4e7230543c9060739c9182))

- Fix trigger date
  ([`da168b7`](https://github.com/opentargets/gentroutils/commit/da168b7153a5b0eb03319e0a248a704604bb9cca))

- Improvements over dev branch tests"
  ([`4597b90`](https://github.com/opentargets/gentroutils/commit/4597b90227306822718c0364db8d8a336282cc95))

- Pr yaml
  ([`c65f137`](https://github.com/opentargets/gentroutils/commit/c65f1379d45bd1f1437fa816fa6fb4e5ae5f4737))

- Prevent second job run and fix build
  ([`422b3fc`](https://github.com/opentargets/gentroutils/commit/422b3fc78dcc869c464e0e722be6619dc444de05))

- Release schedule test
  ([`eaa132e`](https://github.com/opentargets/gentroutils/commit/eaa132ea06694110b969bd4b079f96f32ae80078))

- Release schedule test
  ([`c43d2ab`](https://github.com/opentargets/gentroutils/commit/c43d2ab659ddbc7ec2e22c2c1a07d136a725e4d5))

- Skip no-commit-to-branch on dev test
  ([`e214f6c`](https://github.com/opentargets/gentroutils/commit/e214f6c657eae9ed519cf552fc03639396cb2d45))

- Trigger release from main branch
  ([`9447be8`](https://github.com/opentargets/gentroutils/commit/9447be8627108b7924bcad0750d7c53f2babb100))

- Use original github token for testpypi
  ([`1e2e5af`](https://github.com/opentargets/gentroutils/commit/1e2e5af0aba88c4decf8a471d042b3f8c0487414))

### Documentation

- Added documentation over the cli
  ([`fff60a9`](https://github.com/opentargets/gentroutils/commit/fff60a91a933d075989803f570fea0c8d64ec50c))

- Readme scheleton
  ([`c3c7887`](https://github.com/opentargets/gentroutils/commit/c3c7887f633e89fb153ffd2a8981442e6fb58b92))

### Features

- Added DEV environment
  ([`6a44a9e`](https://github.com/opentargets/gentroutils/commit/6a44a9ede2a9b56a3f58873f458a1843abc3b422))

- Attempt to install rye with cargo
  ([`ce4fd37`](https://github.com/opentargets/gentroutils/commit/ce4fd37ed2483c353bc552e6d9e91b5f9883dc52))

- Gwas curation update script
  ([`31716bf`](https://github.com/opentargets/gentroutils/commit/31716bf7a62c097e19305023f9023b7338e404ee))

- Local pre-commit execution without action
  ([`4345691`](https://github.com/opentargets/gentroutils/commit/4345691c7e3a352b72d5003fbfe5781d7d111c90))

- Package setup
  ([`0c5d4c3`](https://github.com/opentargets/gentroutils/commit/0c5d4c3186ae6ddc18f46e0e76ad690e08c8ec56))

- Pytest setup and cli entrypoint
  ([`c107abd`](https://github.com/opentargets/gentroutils/commit/c107abd843efc6a60c6604e22ca5994fe46d3617))
